@@ -22,7 +22,7 @@ module.exports = {
               ],
             },
             "installation/prompt",
-            "installation/customize"
+            "installation/customize",
           ],
         },
       ],
@@ -66,6 +66,7 @@ module.exports = {
         "segments/dotnet",
         "segments/executiontime",
         "segments/exit",
+        "segments/flutter",
         "segments/git",
         "segments/poshgit",
         "segments/golang",
@@ -80,6 +81,7 @@ module.exports = {
         "segments/nightscout",
         "segments/npm",
         "segments/node",
+        "segments/nx",
         "segments/os",
         "segments/owm",
         "segments/path",
